pub trait Dps310Bus:
Send
+ Sync
+ 'static {
type Error: Debug + Send + 'static;
// Required methods
fn write(&mut self, write: &[u8]) -> Result<(), Self::Error>;
fn write_read(
&mut self,
write: &[u8],
read: &mut [u8],
) -> Result<(), Self::Error>;
}Expand description
Address-scoped bus interface for DPS310 register I/O.
Implement this trait in your board bundle resource type so the driver does not carry or configure an I2C address.
Required Associated Types
Required Methods
fn write(&mut self, write: &[u8]) -> Result<(), Self::Error>
fn write_read( &mut self, write: &[u8], read: &mut [u8], ) -> Result<(), Self::Error>
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".